==> webkit2gtk_2.28.1.orig.tar.xz: webkitgtk-2.28.1/Source/WebCore/Modules/applepay/ApplePaySessionPaymentRequest.cpp <==
/*
 * Copyright (C) 2015-2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "ApplePaySessionPaymentRequest.h"

#if ENABLE(APPLE_PAY)

#include "PaymentAuthorizationStatus.h"
#include <wtf/SoftLinking.h>

namespace WebCore {

ApplePaySessionPaymentRequest::ApplePaySessionPaymentRequest() = default;

ApplePaySessionPaymentRequest::~ApplePaySessionPaymentRequest() = default;

bool isFinalStateResult(const Optional<PaymentAuthorizationResult>& result)
{
    if (!result)
        return true;

    switch (result->status) {
    case PaymentAuthorizationStatus::Success:
    case PaymentAuthorizationStatus::Failure:
        return result->errors.isEmpty();

    case PaymentAuthorizationStatus::PINRequired:
    case PaymentAuthorizationStatus::PINIncorrect:
    case PaymentAuthorizationStatus::PINLockout:
        return false;
    }
}

}

#endif

==> webkit2gtk_2.34.2.orig.tar.xz: webkitgtk-2.34.2/Source/WebCore/Modules/applepay/ApplePaySessionPaymentRequest.cpp <==
/*
 * Copyright (C) 2015-2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "ApplePaySessionPaymentRequest.h"

#if ENABLE(APPLE_PAY)

#include "PaymentAuthorizationStatus.h"
#include <wtf/SoftLinking.h>

namespace WebCore {

ApplePaySessionPaymentRequest::ApplePaySessionPaymentRequest() = default;

ApplePaySessionPaymentRequest::~ApplePaySessionPaymentRequest() = default;

bool isFinalStateResult(const std::optional<PaymentAuthorizationResult>& result)
{
    if (!result)
        return true;

    switch (result->status) {
    case PaymentAuthorizationStatus::Success:
    case PaymentAuthorizationStatus::Failure:
        return result->errors.isEmpty();

    case PaymentAuthorizationStatus::PINRequired:
    case PaymentAuthorizationStatus::PINIncorrect:
    case PaymentAuthorizationStatus::PINLockout:
        return false;
    }
}

}

#endif
